

# This script constructs logistic regression models of observed deviations as a
# function of features of cross-validation and blind data sets.
#
# Author = Yohan Kim
# ykim.biolgy@gmail.com
# April 9th 2014


# Returns a logistic regression model to be saved later:
get_model_logistic <- function(dtab_all, mformula, cutoff_dev) {
  mformula <- paste(mformula, collapse="+")
  mformula <- paste("cbind(ybad,ygood)~", mformula)
  mformula <- as.formula(mformula)

  if (cutoff_dev == 0) {
      #Calculate if none provided.
      cutoff_dev <- mean(dtab_all$deviation)
  }

  # Provide labels for the observed deviations:
  ybad  <- dtab_all$deviation > cutoff_dev  # Large deviations.
  ygood <- dtab_all$deviation < cutoff_dev  # Small deviations.
    
  model <- glm(mformula, family=binomial(logit), data=dtab_all)
  model
}


fname <- 'table.logistic_pred.model_type_and.smmpmbec_cpp_rerun.auc.xls'
#fname <- 'table.logistic_pred.model_type_and.netmhc.auc.xls'
#fname <- 'table.logistic_pred.model_type_and.netmhcpan.auc.xls'
dtab <- read.table(fname, header=T)


# Logistic regression model built using features only from the cross-validation data sets:
mformula_cv <- c('log_size_cv',  'ent_meas_cv')

# Logistic regression model built using features only from the blind data sets:
mformula_bl <- c('entss_bl',  'ent_pred_bl')


cutoff_dev <- mean(dtab$deviation)

model_cv <- get_model_logistic(dtab, mformula_cv, cutoff_dev)
prob_cv <- predict(model_cv, dtab, type="response")

model_bl <- get_model_logistic(dtab, mformula_bl, cutoff_dev)
prob_bl <- predict(model_bl, dtab, type="response")


#plot(dtab$model_dev.prob, ypred)
plot(dtab$deviation, prob_cv, xlab='Observed Deviation', ylab='Predicted prob of large deviation')

